==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/core/icontourfilter.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef ICONTOURFILTER_H
#define ICONTOURFILTER_H


#include "igenericfilter.h"
#include <vtkToolkits.h>


#include "ivtk.h"

#if defined(VTK_USE_PATENTED) || !defined(IVTK_4)
#include <vtkMarchingContourFilter.h>
#define IVTK_CONTOURFILTER		vtkMarchingContourFilter
#else
#include <vtkContourFilter.h>
#define IVTK_CONTOURFILTER		vtkContourFilter
#endif


class iContourFilter : public iGenericFilter<IVTK_CONTOURFILTER,vtkImageData,vtkPolyData>
{
	
public:

	static iContourFilter* New();
	
protected:

	virtual void ProduceOutput(vtkImageData *input, vtkPolyData *output);
};

#endif // ICONTOURFILTER_H

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/core/icontourfilter.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef ICONTOURFILTER_H
#define ICONTOURFILTER_H


#include "igenericfilter.h"
#include <vtkDataSetToPolyDataFilter.h>


class iContourFilter : public iGenericFilter<vtkDataSetToPolyDataFilter,vtkDataSet,vtkPolyData>
{
	
	IGENERICFILTER_DECLARE(iContourFilter);

public:

	inline int GetCurrentVar() const { return mCurVar; }
	void SetCurrentVar(int n);
	
	float GetLevel() const;
	void SetLevel(float);

protected:

	virtual ~iContourFilter();

	virtual void ProduceOutput();

	int mCurVar;
	vtkObject *mWorker;
};

#endif // ICONTOURFILTER_H
